"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const puppeteer_core_1 = __importDefault(require("puppeteer-core"));
const utils_1 = require("./utils");
let browser, page;
module.exports = async function (data) {
    try {
        // Whether or not it starts with the http protocol
        data.url = (0, utils_1.isHttp)(data.url) ? data.url : 'http://' + data.url;
        const launchOpt = await (0, utils_1.launch)();
        if (!browser)
            browser = await puppeteer_core_1.default.launch(launchOpt);
        // Creating a new tab
        page = await browser.newPage();
        // Setting the screenshot aspect ratio
        if (data.viewport) {
            const viewport = data.viewport.split('x');
            if (viewport.length === 1)
                viewport.push(viewport[0]);
            data.viewport = {
                width: parseInt(viewport[0]),
                height: parseInt(viewport[1]),
                isMobile: (0, utils_1.isBoolean)(data.isMobile)
            };
            await page.setViewport(data.viewport); // Setting the page size
        }
        // open a website
        const gotoOpt = (0, utils_1.goto)(data);
        await page.goto(data.url, gotoOpt);
        const screenshotOpt = (0, utils_1.screenshot)(data);
        // Wait after page rendering is complete (milliseconds)
        await new Promise((r) => setTimeout(r, (gotoOpt.await || 0) + 1000));
        return (await page.screenshot(screenshotOpt));
    }
    catch (error) {
        // eslint-disable-next-line
        console.error(error);
        if (browser) {
            browser.close();
            browser = null;
        }
    }
    finally {
        if (page) {
            await page.close();
            page = null;
        }
    }
    return '';
};
