"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cache = exports.screenshot = exports.goto = exports.launch = exports.clip = exports.deepClone = exports.isValidKey = exports.isHttp = exports.isNumber = exports.isBoolean = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const os_1 = require("os");
const path_1 = require("path");
const fs_1 = require("fs");
const args_1 = require("./args");
const { WEBSTACK_SCREENSHOT_SERVERLESS, WEBSTACK_SCREENSHOT_FONTS, WEBSTACK_SCREENSHOT_PUPPETEER_EXECUTABLE_PATH } = process.env;
const TMP_DIR_PATH = (0, path_1.join)((0, os_1.tmpdir)(), 'WebStack-Screenshot');
if (!(0, fs_1.existsSync)(TMP_DIR_PATH))
    (0, fs_1.mkdirSync)(TMP_DIR_PATH, { recursive: true });
function isBoolean(value) {
    return value === 'true' || value === true ? true : false;
}
exports.isBoolean = isBoolean;
function isNumber(value) {
    return !isNaN(value);
}
exports.isNumber = isNumber;
function isHttp(url) {
    return /^https?:\/\//.test(url);
}
exports.isHttp = isHttp;
const isValidKey = (key, object) => key in object;
exports.isValidKey = isValidKey;
function deepClone(data) {
    try {
        return JSON.parse(JSON.stringify(data));
    }
    catch (error) {
        return {};
    }
}
exports.deepClone = deepClone;
function clip(data) {
    if (!data.clip)
        return;
    const clip = data.clip.split(',');
    const opt = {
        x: parseInt(clip[0]),
        y: parseInt(clip[1]),
        width: parseInt(clip[2]),
        height: parseInt(clip[3])
    };
    return opt;
}
exports.clip = clip;
async function launch() {
    const options = {
        args: args_1.args,
        defaultViewport: {
            height: 1080,
            width: 1920
        }
    };
    // lambda (ServerLess)
    const lambdaOptions = options;
    if (WEBSTACK_SCREENSHOT_SERVERLESS) {
        const chromium = (await Promise.resolve().then(() => __importStar(require('@sparticuz/chromium')))).default;
        // install font
        if (WEBSTACK_SCREENSHOT_FONTS) {
            const fonts = (WEBSTACK_SCREENSHOT_FONTS || '').split(',').filter(Boolean);
            await Promise.all(fonts.map((font) => chromium.font(font)));
        }
        lambdaOptions.executablePath = await chromium.executablePath();
        return lambdaOptions;
    }
    // local (Server)
    const localOptions = options;
    const { executablePath } = (await Promise.resolve().then(() => __importStar(require('puppeteer'))));
    localOptions.executablePath = executablePath();
    if (WEBSTACK_SCREENSHOT_PUPPETEER_EXECUTABLE_PATH) {
        localOptions.executablePath = WEBSTACK_SCREENSHOT_PUPPETEER_EXECUTABLE_PATH;
    }
    return localOptions;
}
exports.launch = launch;
function goto(data) {
    const options = {};
    // Timeout, default 30s
    if (isNumber(data.timeout)) {
        options.timeout = Math.abs(data.timeout) ?? 30000;
    }
    // Wait after the page is rendered (milliseconds)
    if (isNumber(data.await))
        options.await = Math.abs(data.await) || 0;
    // When do you trigger the screenshot?
    const waitUntils = [
        'load',
        'domcontentloaded',
        'networkidle0',
        'networkidle2' // When there are only 2 requests within 500ms
    ];
    options.waitUntil = waitUntils.includes(data.waitUntil) ? data.waitUntil : waitUntils[0];
    return options;
}
exports.goto = goto;
function screenshot(data) {
    const options = {};
    // Image quality between 0-100, ignored if the image type is png
    options.quality = 50;
    if (isNumber(data.quality))
        options.quality = Math.abs(data.quality);
    // Image type
    const types = ['jpeg', 'png', 'webp'];
    options.type = types.includes(data.type) ? data.type : types[0];
    // Image encoding
    const encodings = ['binary', 'base64'];
    options.encoding = encodings.includes(data.encoding) ? data.encoding : encodings[0];
    // Screenshot of the full page
    options.fullPage = isBoolean(data.fullPage);
    // Intercepts the specified coordinates and width and height
    const clipOpt = clip(data);
    if (clipOpt)
        options.clip = clipOpt;
    return options;
}
exports.screenshot = screenshot;
function cache(cache) {
    // Do not use http forced caching
    if (cache === 'false')
        return;
    const sec = Math.abs(cache);
    const daySec = 86400;
    const cacheKey = 'public, no-transform, s-maxage=$, max-age=$';
    // eslint-disable-next-line eqeqeq
    if (cache == void 0)
        return cacheKey.replace(/\$/g, daySec);
    if (isNumber(sec))
        return cacheKey.replace(/\$/g, sec);
}
exports.cache = cache;
